
package cl.uchile.cc10a.io.console;

import java.awt.Button;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Event;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.Label;
import java.awt.Panel;
import java.awt.Point;

/**
 * FatalError class
 *
 * A class to display an error message and then terminate the
 * programs execution.
 *
 * Full documentation for the classes in the hsa package available at: 
 *			http://www.holtsoft.com/java/hsa_package.html
 *
 * @author Tom West
 * @version 1.0, Jan 1, 1998
 */
public class FatalError extends Frame 
{
	private Button	quitButton;

/**
 * Contructor - FatalError to be displayed on centre of screen.
 *
 * @param message The message to be displayed in the FatalError dialog box.
 */
public FatalError (String message)
{
	this (message, null);
} // Constructor - FatalError (String)
/**
 * Contructor - FatalError to be displayed on centre of a specified Frame.
 *
 * @param message The message to be displayed in the FatalError dialog box.
 * @param frame The Frame that the dialog box should be centred on.
 */
public FatalError (String message, Frame frame)
{
	// Create the window
	super ("Fatal Error");

	setBackground (Color.lightGray);
	
	// Put the message at the top
	this.add ("Center", new Label ("  " + message + "  ", Label.CENTER));

	// Put OK button at bottom
	quitButton = new Button ("Quit");
	Panel p = new Panel ();
	p.setLayout (new FlowLayout (FlowLayout.CENTER, 0, 0));
	p.add (quitButton);
	add ("South", p);

	pack ();

	Dimension dlg = getSize ();
	Point loc;
	if (frame == null)
	{
		// Place frame in middle of the screen
		Dimension screen = getToolkit ().getScreenSize ();
		loc = new Point ((screen.width - dlg.width) / 2,
			(screen.height - dlg.height) / 3);
	}
	else
	{
		Dimension window = frame.getSize ();
		Point windowLoc = frame.getLocation ();
		loc = new Point (windowLoc.x + (window.width - dlg.width) / 2,
			windowLoc.y + (window.height - dlg.height) / 3);
	}	
	setLocation (loc);
			
	show ();
	toFront ();
	waitUntilDone ();
	System.exit (0);
} // Constructor - FatalError (String, Frame)

/**
 * Act upon the user hitting the OK button
 */
public synchronized boolean action (Event e, Object arg)
{
	if (e.target == quitButton)
	{
	    this.hide ();
	    notifyAll ();
	    return (true);
	}
	return (false);
} // action (Event, Object)
/**
  * Overrides the handleEvent method.  It handles window being closed.
	*/
public synchronized boolean handleEvent (Event evt)
{
	switch (evt.id)
	{
		case Event.WINDOW_DESTROY:
	    this.hide ();
	    notifyAll ();
	    return (true);
	}
	return super.handleEvent (evt);
} // handleEvent (Event)
/**
 * Waits until the user has pressed OK or hit enter.
 */
private synchronized void waitUntilDone ()
{
	Message.beep ();
	
	// Pause until button wakes us up
	try
	{
	    wait ();
	}
	catch (InterruptedException e)
	{
	    ;
	}
	dispose ();
} // waitUntilDone (void)
} /* FatalError class */
